import { Message, Role } from "discord.js";
import { ICordeBot, IMessageEmbed, IRoleData, IRoleIdentifier } from "../types";
export declare class Bot {
  private _bot;
  /**
   * Gets the voice channel state that corde's bot is connected in, If it's connected.
   * This property is filled when `joinVoiceChannel()` connects to a channel
   * and is cleared when `leaveVoiceChannal()` is called.
   */
  get voiceState(): import("../types").IVoiceChannelState | undefined;
  /**
   * Checks if corde's bot is connected and ready.
   */
  get isLoggedIn(): boolean;
  constructor(bot: ICordeBot);
  /**
   * Checks if a given message was sent by corde's bot
   * @param message Sent message
   * @returns If corde's bot is the author of the message
   */
  isMessageAuthor(message: Message): boolean;
  /**
   * Joins corde's bot to a voice channel.
   * @param channelId Voice channel to corde's bot connect
   * @returns Voice connection state. This property can be get from `bot.voiceState`
   */
  joinVoiceChannel(channelId: string): Promise<import("../types").IVoiceChannelState>;
  /**
   * Leaves a voice channel.
   */
  leaveVoiceChannel(): void;
  /**
   * Checks if corde's bot is in a voice channel
   */
  isInVoiceChannel(): boolean;
  /**
   * Makes a fetch of a channel based on it's `id`.
   * @param id Id of the channel
   * @returns Channel if it's found
   */
  fetchChannel(id: string): Promise<import("discord.js").Channel | undefined>;
  /**
   * Makes a fetch of a guild based on it's `id`.
   * @param id Id of the guild
   * @returns Guild if it's found
   */
  fetchGuild(id: string): Promise<import("discord.js").Guild | undefined>;
  /**
   * Gets the channel defined in `configs`
   */
  getChannel(): import("discord.js").TextChannel;
  /**
   * Gets the guild defined in `configs`
   */
  getGuild(): import("discord.js").Guild;
  /**
   * Search for a guild in guild's cache, based on it's id
   * @param id id of the guild
   * @returns Guild if the id is valid and the guild is in the cache
   */
  findGuild(id: string): import("discord.js").Guild;
  /**
   * Sends a message to the connected textChannel.
   *
   * **This function does not work without a test case**
   *
   * @param message Message to send
   *
   * @example
   *
   * // Works
   * test("test 1", () => {
   *    const message = await sendMessage("msg");
   *    expect(`editMessage ${message.id}`).toEditMessage({ id: message.id }, "newValue");
   * });
   *
   * // Do not Works
   * group("test 1", () => {
   *    const message = await sendMessage("msg");
   * });
   *
   * @throws CordeClienteError - If bot is not connected yet.
   *
   * @returns null if message is empty, null or undefined.
   * Message if **message** is not empty and it was send to Discord.
   *
   * @since 2.0
   */
  send(message: string | number | boolean | bigint): Promise<Message>;
  send(message: IMessageEmbed): Promise<Message>;
  /**
   * Creates a new role to the guild provided in configs.
   *
   * @param roleIdentifier Basic informations about the role.
   * @see https://cordejs.org/docs/configurations#guildid
   *
   * @throws CordeClientError if corde has not yet connect it's bot.
   * @returns A promise that return the created role.
   *
   * @since 2.1
   */
  createRole(data: IRoleData): Promise<Role>;
  /**
   * Finds a role in config guild's cache, basing on it's **id**
   *
   * @param id Id of the role.
   * @throws CordeClientError if corde's bot is not connected.
   * @returns Role that matches the provided **id** or **name**
   */
  findRole(id: string): Role | undefined;
  /**
   * Finds a role in config guild's cache, basing on it's **id** or **name**.
   *
   * @param data Data of the role. It can be it's **name** or **id**.
   *
   * if both informations be provided, and they are from two differents
   * roles, the result will correspond to the role that matchs with the parameter
   * **id**.
   *
   * @throws CordeClientError if corde's bot is not connected.
   * @returns Role that matches the provided **id** or **name**
   */
  findRole(data: IRoleIdentifier): Role | undefined;
  private _findRole;
}
